---
title: "Messages"
parent: "@messageformat/runtime"
grand_parent: API Reference
---

<!-- Do not edit this file. It is automatically generated by API Documenter. -->



# Messages class

Accessor class for compiled message functions generated by [compileModule()](./core.compilemodule.md)

<b>Signature:</b>

```typescript
export default class Messages 
```

## Remarks


```js
import Messages from '@messageformat/runtime/messages'

```

## Example


```js
// build.js
import { writeFileSync } from 'fs';
import MessageFormat from '@messageformat/core';

const mf = new MessageFormat(['en', 'fi']);
const msgSet = {
  en: {
    a: 'A {TYPE} example.',
    b: 'This has {COUNT, plural, one{one user} other{# users}}.',
    c: {
      d: 'We have {P, number, percent} code coverage.'
    }
  },
  fi: {
    b: 'Tällä on {COUNT, plural, one{yksi käyttäjä} other{# käyttäjää}}.',
    e: 'Minä puhun vain suomea.'
  }
};
writeFileSync('messages.js', String(mf.compile(msgSet)));

```

```js
// runtime.js
import Messages from '@messageformat/runtime/messages';
import msgData from './messages';

const messages = new Messages(msgData, 'en');

messages.hasMessage('a')                // true
messages.hasObject('c')                 // true
messages.get('b', { COUNT: 3 })         // 'This has 3 users.'
messages.get(['c', 'd'], { P: 0.314 })  // 'We have 31% code coverage.'

messages.get('e')                       // 'e'
messages.setFallback('en', ['foo', 'fi'])
messages.get('e')                       // 'Minä puhun vain suomea.'

messages.locale = 'fi'
messages.hasMessage('a')                // false
messages.hasMessage('a', 'en')          // true
messages.hasMessage('a', null, true)    // true
messages.hasObject('c')                 // false
messages.get('b', { COUNT: 3 })         // 'Tällä on 3 käyttäjää.'
messages.get('c').d({ P: 0.628 })       // 'We have 63% code coverage.'

```

## Constructors

|  Constructor | Modifiers | Description |
|  --- | --- | --- |
|  [(constructor)(msgData, defaultLocale)](./runtime.messages._constructor_.md) |  | Constructs a new instance of the <code>Messages</code> class |

## Properties

|  Property | Modifiers | Type | Description |
|  --- | --- | --- | --- |
|  [availableLocales](./runtime.messages.availablelocales.md) |  | string\[\] | Read-only list of available locales |
|  [defaultLocale](./runtime.messages.defaultlocale.md) |  | string \| null | Default fallback locale |
|  [locale](./runtime.messages.locale.md) |  | string \| null | Current locale |

## Methods

|  Method | Modifiers | Description |
|  --- | --- | --- |
|  [addMessages(data, locale, keypath)](./runtime.messages.addmessages.md) |  | Add new messages to the accessor; useful if loading data dynamically |
|  [get(key, props, locale)](./runtime.messages.get.md) |  | Get the message or object corresponding to <code>key</code> |
|  [getFallback(locale)](./runtime.messages.getfallback.md) |  | Get the list of fallback locales |
|  [hasMessage(key, locale, fallback)](./runtime.messages.hasmessage.md) |  | Check if <code>key</code> is a message function for the locale |
|  [hasObject(key, locale, fallback)](./runtime.messages.hasobject.md) |  | Check if <code>key</code> is a message object for the locale |
|  [resolveLocale(locale)](./runtime.messages.resolvelocale.md) |  | Resolve <code>lc</code> to the key of an available locale or <code>null</code>, allowing for partial matches. |
|  [setFallback(lc, fallback)](./runtime.messages.setfallback.md) |  | Set the fallback locale or locales for <code>lc</code> |

